<?php
/**
 * @file
 * TogMine drush command to execute TogMine for all valid accounts.
 */


/**
 * Implementation of hook_drush_command().
 */
function togmine_drush_command() {
  $items = array();

  // The key in the $items array is the name of the command.
  $items['togmine-pull-time-entries'] = array(
    'description' => 'Pulls Toggl.com time entries into Redmine issues.',
    'callback arguments' => array('pull_time_entries'),
  );

  $items['togmine-push-projects'] = array(
    'description' => 'Pushes Redmine projects to Toggl.com and maintains the map of Redmine to Toggl.com project IDs.',
    'callback arguments' => array('push_projects'),
  );

  $items['togmine-push-issues'] = array(
    'description' => 'Pushes Redmine issues to Toggl.com as auto-complete suggestions (time entries) to help with the accuracy of time-logging in Toggl.com.',
    'callback arguments' => array('push_issues'),
  );

  foreach (array_keys($items) as $key) {
    $items[$key]['drupal dependencies'] = array('togmine');
    $items[$key]['callback'] = 'togmine_drush_command_callback';
  }

  return $items;
}

/**
 * Implementation of hook_drush_help().
 */
function togmine_drush_help($section) {
  switch ($section) {
    case 'meta:togmine:title': {
      return dt('TogMine commands');
    }
    case 'meta:togmine:summary': {
      return dt('@TODO Where does this help string appear?');
    }
  }
}

/**
 * A drush command callback.
 */
function togmine_drush_command_callback($command) {
  $synchronizer = togmine_execute_command($command);

  // Save the result object for later use.
  variable_set("togmine_{$command}_last_synchronization", $synchronizer);

  if ($synchronizer->message) {
    // Log the message to watchdog, which also outputs on the command line.
    // Drush prints watchdog messages to screen too.
    watchdog('togmine', $synchronizer->message, array(), !$synchronizer->success ? WATCHDOG_ERROR : ($synchronizer->warning ? WATCHDOG_WARNING : WATCHDOG_INFO));
  }

  if (togmine_var('debug')) {
    // Log more detail in debug mode.
    // Don't repeat the message.
    unset($synchronizer->message);
    watchdog('togmine', '<pre>!debug</pre>', array('!debug' => var_export($synchronizer, TRUE)), WATCHDOG_DEBUG);
    rest_api_query_var_export($synchronizer, 'TogMine Result');
  }
}
